@@ -42,6 +42,9 @@ class SnapReviewSecurity(SnapReview):
                                   'os',
                                   'kernel']  # these don't need security items
 
+        self.sec_safe_slots = ['content',
+                               'mpris']
+
     def check_security_policy_vendor(self):
         '''Check policy-vendor'''
         if not self.is_snap2:
@@ -76,7 +79,7 @@ class SnapReviewSecurity(SnapReview):
             return  # not in aa_policy
 
         o = self._devmode_override()
-        if name.endswith('slot'):
+        if name.endswith('slot') and interface not in self.sec_safe_slots:
             t = 'warn'
             n = self._get_check_name('is_slot', app=iface,
                                      extra=interface)
@@ -86,13 +89,6 @@ class SnapReviewSecurity(SnapReview):
                 m = True
             self._add_result(t, n, s, manual_review=m, override_result_type=o)
 
-        # Note: snapd typically doesn't autoconnect by default except for known
-        # safe interfaces like network and network-bind. As such, these tests
-        # add extra maintenance overhead since the store and snappy would
-        # ideally agree. However, until assertions are implemented, keep these
-        # checks and mark the autoconnect ones as 'common' and the
-        # non-autoconnect as 'reserved'. Eventually we will probably move all
-        # of these to 'common'.
         t = 'info'
         n = self._get_check_name('%s_safe' % name, app=iface, extra=interface)
         s = "OK"
@@ -200,24 +196,19 @@ class SnapReviewSecurity(SnapReview):
             t = 'info'
             n = self._get_check_name('profile_name_length', app=app)
             s = "OK"
-            profile = "%s_%s_%s" % (self.snap_yaml['name'],
-                                    app,
-                                    self.snap_yaml['version'])
+            profile = "snap.%s.%s" % (self.snap_yaml['name'], app)
             if len(profile) > maxlen:
                 t = 'error'
                 s = ("'%s' too long (exceeds %d characters). Please shorten "
-                     "'%s', '%s' and/or '%s'" % (profile, maxlen,
-                                                 self.snap_yaml['name'],
-                                                 app,
-                                                 self.snap_yaml['version']))
+                     "'%s' and/or '%s'" % (profile, maxlen,
+                                           self.snap_yaml['name'], app))
             elif len(profile) > advlen:
                 t = 'warn'
                 s = ("'%s' is long (exceeds %d characters) and thus could be "
                      "problematic in certain environments. Please consider "
-                     "shortening '%s', '%s' and/or '%s'" % (profile, advlen,
-                                                            self.snap_yaml['name'],
-                                                            app,
-                                                            self.snap_yaml['version']))
+                     "shortening '%s' and/or '%s'" % (profile, advlen,
+                                                      self.snap_yaml['name'],
+                                                      app))
             self._add_result(t, n, s)
 
     def check_squashfs_resquash(self):
