@@ -900,6 +900,17 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    def test_check_hooks_missing_apparmor_with_puritine(self):
+        '''Test check_hooks() - missing apparmor'''
+        self.set_test_manifest("framework", "ubuntu-sdk-13.10")
+        c = ClickReviewLint(self.test_name)
+        del c.manifest['hooks'][self.default_appname]['apparmor']
+        c.manifest['hooks'][self.default_appname]['puritine'] = 'foo'
+        c.check_hooks()
+        r = c.click_report
+        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_hooks_has_desktop_and_scope(self):
         '''Test check_hooks() - desktop with scope'''
         self.set_test_manifest("framework", "ubuntu-sdk-13.10")
@@ -997,6 +1008,18 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         name = c._get_check_name('hooks_redflag', app='test-app')
         self.check_manual_review(r, name)
 
+    def test_check_hooks_redflagged_puritine(self):
+        '''Test check_hooks_redflagged() - puritine'''
+        self.set_test_manifest("framework", "ubuntu-sdk-13.10")
+        c = ClickReviewLint(self.test_name)
+        c.manifest['hooks'][self.default_appname]["puritine"] = "foo"
+        c.check_hooks_redflagged()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        name = c._get_check_name('hooks_redflag', app='test-app')
+        self.check_manual_review(r, name)
+
     def test_pkgname_toplevel(self):
         '''Test check_pkgname - toplevel'''
         self.set_test_manifest("name", "foo")
@@ -1950,6 +1973,32 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
+    def test_check_external_symlinks_puritine(self):
+        '''Test check_external_symlinks - puritine'''
+        self.set_test_manifest("framework", "ubuntu-sdk-13.10")
+        c = ClickReviewLint(self.test_name)
+        c.manifest['hooks'][self.default_appname]["puritine"] = "foo"
+        c.check_external_symlinks()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+        name = c._get_check_name('external_symlinks')
+        m = r['info'][name]['text']
+        self.assertIn("SKIPPED: puritine", m)
+
+    def test_check_md5sums_puritine(self):
+        '''Test check_md5sums - puritine'''
+        self.set_test_manifest("framework", "ubuntu-sdk-13.10")
+        c = ClickReviewLint(self.test_name)
+        c.manifest['hooks'][self.default_appname]["puritine"] = "foo"
+        c.check_md5sums()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+        name = c._get_check_name('md5sums')
+        m = r['info'][name]['text']
+        self.assertIn("SKIPPED: puritine", m)
+
 
 class ClickReviewLintTestCase(TestCase):
     """Tests without mocks where they are not needed."""
