@@ -6,7 +6,7 @@ import glob
 class TestModules(cr_tests.TestClickReview):
     '''Tests for the modules module.'''
     def setUp(self):
-        self.cr_modules = modules.get_modules()
+        self.modules = modules.get_modules()
         super().setUp()
 
     def test_number_of_suitable_modules(self):
@@ -14,17 +14,17 @@ class TestModules(cr_tests.TestClickReview):
         module_files = glob.glob(path + '/*.py')
         relevant_module_files = modules.narrow_down_modules(module_files)
         self.assertEqual(len(relevant_module_files),
-                         len(self.cr_modules))
+                         len(self.modules))
 
     def test_number_of_suitable_modules_greater0(self):
-        self.assertTrue(len(self.cr_modules) > 0)
+        self.assertTrue(len(self.modules) > 0)
 
     def test_number_of_available_review_classes(self):
         count = 0
-        for module_name in self.cr_modules:
+        for module_name in self.modules:
             review = modules.find_main_class(module_name)
             if review:
                 count += 1
-        self.assertEqual(count, len(self.cr_modules),
-                         'Not all files in clickreviews/cr_*.py contain '
-                         'classes named Click*Review.')
+        self.assertEqual(count, len(self.modules),
+                         'Not all files in clickreviews/[cs]r_*.py contain '
+                         'classes named Click|Snap*Review.')
