@@ -213,15 +213,13 @@ class TestSnapReviewSecurity(sr_tests.TestSnapReview):
                                   "manual_review": False}
         self.check_results(report, expected=expected)
 
-    def test_check_security_plugs_reserved_snapd_control(self):
-        ''' Test check_security_plugs() - reserved (snapd-control)'''
-        plugs = self._create_top_plugs()
-        plugs['snapd-control'] = {}
-        self.set_test_snap_yaml("plugs", plugs)
+    def test_check_security_plugs_no_plugs(self):
+        ''' Test check_security_plugs() - no plugs'''
+        self.set_test_snap_yaml("plugs", None)
         c = SnapReviewSecurity(self.test_name)
         c.check_security_plugs()
         report = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
         self.check_results(report, expected_counts)
 
     def test_check_security_plugs_unknown_type(self):
@@ -273,8 +271,8 @@ class TestSnapReviewSecurity(sr_tests.TestSnapReview):
         expected['info'][name] = {"text": "OK"}
         self.check_results(report, expected=expected)
 
-    def test_check_security_apps_plugs_none(self):
-        ''' Test check_security_apps_plugs() - None'''
+    def test_check_security_apps_plugs_no_apps(self):
+        ''' Test check_security_apps_plugs() - No apps'''
         self.set_test_snap_yaml("apps", None)
         c = SnapReviewSecurity(self.test_name)
         c.check_security_apps_plugs()
@@ -282,6 +280,16 @@ class TestSnapReviewSecurity(sr_tests.TestSnapReview):
         expected_counts = {'info': 0, 'warn': 0, 'error': 0}
         self.check_results(report, expected_counts)
 
+    def test_check_security_apps_plugs_none(self):
+        ''' Test check_security_apps_plugs() - app with no plugs'''
+        apps = {'app1': {'plugs': {}}}
+        self.set_test_snap_yaml("apps", apps)
+        c = SnapReviewSecurity(self.test_name)
+        c.check_security_apps_plugs()
+        report = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
     def test_check_security_apps_plugs_bad(self):
         ''' Test check_security_apps_plugs() - bad'''
         apps = {'app1': {'plugs': [{}]}}
@@ -313,6 +321,30 @@ class TestSnapReviewSecurity(sr_tests.TestSnapReview):
         expected_counts = {'info': 2, 'warn': 2, 'error': 0}
         self.check_results(report, expected_counts)
 
+    def test_check_security_slots_mpris(self):
+        ''' Test check_security_slots() - mpris'''
+        slots = dict()
+        slots['mpris'] = {}
+        self.set_test_snap_yaml("slots", slots)
+        c = SnapReviewSecurity(self.test_name)
+        c.check_security_slots()
+        report = c.click_report
+        # specifying slots currently requires manual review, unless a safe slot
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_security_slots_content(self):
+        ''' Test check_security_slots() - content'''
+        slots = dict()
+        slots['content'] = {}
+        self.set_test_snap_yaml("slots", slots)
+        c = SnapReviewSecurity(self.test_name)
+        c.check_security_slots()
+        report = c.click_report
+        # specifying slots currently requires manual review, unless a safe slot
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
     def test_check_security_slots_none(self):
         ''' Test check_security_slots() - None'''
         self.set_test_snap_yaml("slots", None)
